
giving.gvr
==========

.. automodule:: giving.gvr

    .. autoclass:: Giver
        :members:
    .. autofunction:: register_special
    .. autofunction:: resolve
    .. autoclass:: LinePosition
        :members:
